============
bettersocket
============


.. image:: https://img.shields.io/pypi/v/bettersocket.svg
        :target: https://pypi.python.org/pypi/bettersocket

.. image:: https://img.shields.io/travis/marcsello/bettersocket.svg
        :target: https://travis-ci.com/marcsello/bettersocket

.. image:: https://readthedocs.org/projects/bettersocket/badge/?version=latest
        :target: https://bettersocket.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Painless socket handing for Python


* Free software: MIT license
* Documentation: https://bettersocket.readthedocs.io.


Features
--------

- Implements a framing mechanism over raw sockets using delimiters.
- Works with both blocking and nonblocking sockets.


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
